// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTAUTOGENERATETEXT_VERSION_H
#define TEXTAUTOGENERATETEXT_VERSION_H

#define TEXTAUTOGENERATETEXT_VERSION_STRING "2.1.0"
#define TEXTAUTOGENERATETEXT_VERSION_MAJOR 2
#define TEXTAUTOGENERATETEXT_VERSION_MINOR 1
#define TEXTAUTOGENERATETEXT_VERSION_PATCH 0
#define TEXTAUTOGENERATETEXT_VERSION ((2<<16)|(1<<8)|(0))

#endif
